==> ddd-3.2.1.tar.gz: ddd-3.2.1/ddd/FontFixBox.h <==
// $Id: FontFixBox.h,v 1.11 1999/08/19 11:27:28 andreas Exp $
// `Freese' font size changes

// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@gnu.org>.
// 
// This file is part of DDD.
// 
// DDD is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// DDD is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public
// License along with DDD -- see the file COPYING.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.gnu.org/software/ddd/',
// or send a mail to the DDD developers <ddd@gnu.org>.

#ifndef _DDD_FontFixBox_h
#define _DDD_FontFixBox_h

#ifdef __GNUG__
#pragma interface
#endif


#include "HatBox.h"


// FontFixBox

class FontFixBox: public HatBox {
    DECLARE_TYPE_INFO

protected:
    FontFixBox(const FontFixBox& box):
	HatBox(box)
    {}

    void dump(ostream& s) const;

public:
    FontFixBox(Box *box, char *t = "FontFixBox"):
	HatBox(box, t)
    {}

    Box *dup() const { return new FontFixBox(*this); }

    void newFont(const string&) {} // font change stops here
};

#endif

==> ddd-3.3.tar.gz: ddd-3.3/ddd/FontFixBox.h <==
// $Id: FontFixBox.h,v 1.12 2000/12/11 12:21:47 zeller Exp $
// `Freese' font size changes

// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@gnu.org>.
// 
// This file is part of DDD.
// 
// DDD is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// DDD is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public
// License along with DDD -- see the file COPYING.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.gnu.org/software/ddd/',
// or send a mail to the DDD developers <ddd@gnu.org>.

#ifndef _DDD_FontFixBox_h
#define _DDD_FontFixBox_h

#ifdef __GNUG__
#pragma interface
#endif


#include "HatBox.h"


// FontFixBox

class FontFixBox: public HatBox {
    DECLARE_TYPE_INFO

protected:
    FontFixBox(const FontFixBox& box):
	HatBox(box)
    {}

    void dump(ostream& s) const;

public:
    FontFixBox(Box *box, const char *t = "FontFixBox"):
	HatBox(box, t)
    {}

    Box *dup() const { return new FontFixBox(*this); }

    void newFont(const string&) {} // font change stops here
};

#endif
